@@ -63,6 +63,7 @@ struct _NautilusBurnPrivate
 	guint                  empty : 1;
 
 	guint                  start_monitor_id;
+	guint                  empty_update_id;
 
 	GSList                *widget_list;
 };
@@ -508,7 +509,8 @@ dir_is_empty (const char *uri)
 		}
 
 		/* Skip "." and "..".  */
-		if (info->name [0] == '.'
+		if (info->name != NULL
+		    && info->name [0] == '.'
 		    && (info->name [1] == 0
 			|| (info->name [1] == '.' && info->name [2] == 0))) {
 			gnome_vfs_file_info_clear (info);
@@ -587,25 +589,16 @@ update_widget_sensitivity (GtkWidget    *widget,
 	gtk_widget_set_sensitive (widget, !burn->priv->empty);
 }
 
-static void
-burn_monitor_cb (GnomeVFSMonitorHandle    *handle,
-		 const gchar              *text_uri,
-		 const gchar              *info_uri,
-		 GnomeVFSMonitorEventType  event_type,
-		 gpointer                  data)
+static gboolean
+update_empty_idle (NautilusBurn *burn)
 {
-	NautilusBurn *burn;
-	gboolean      is_empty;
+	gboolean is_empty;
 
-	burn = NAUTILUS_BURN (data);
+	burn->priv->empty_update_id = 0;
 
-	is_empty = burn->priv->empty;
+	is_empty = dir_is_empty ("burn:///");
 
-	if (event_type == GNOME_VFS_MONITOR_EVENT_CREATED) {
-		is_empty = FALSE;
-	} else if (event_type == GNOME_VFS_MONITOR_EVENT_DELETED) {
-		is_empty = dir_is_empty ("burn:///");
-	}
+	DEBUG_PRINT ("Dir is %s\n", is_empty ? "empty" : "not empty");
 
 	if (burn->priv->empty != is_empty) {
 		burn->priv->empty = is_empty;
@@ -615,6 +608,43 @@ burn_monitor_cb (GnomeVFSMonitorHandle    *handle,
 		/* Trigger update for menu items */
 		nautilus_menu_provider_emit_items_updated_signal (NAUTILUS_MENU_PROVIDER (burn));
 	}
+
+	return FALSE;
+}
+
+static void
+queue_update_empty (NautilusBurn *burn)
+{
+	if (burn->priv->empty_update_id != 0) {
+		g_source_remove (burn->priv->empty_update_id);
+	}
+
+	burn->priv->empty_update_id = g_idle_add ((GSourceFunc)update_empty_idle, burn);
+}
+
+static void
+burn_monitor_cb (GnomeVFSMonitorHandle    *handle,
+		 const gchar              *text_uri,
+		 const gchar              *info_uri,
+		 GnomeVFSMonitorEventType  event_type,
+		 gpointer                  data)
+{
+	NautilusBurn *burn;
+
+	burn = NAUTILUS_BURN (data);
+
+	DEBUG_PRINT ("Monitor callback type %d: %s: %s\n", event_type, text_uri, info_uri);
+
+	/* only queue the action if it has a chance of changing the state */
+	if (event_type == GNOME_VFS_MONITOR_EVENT_CREATED) {
+		if (burn->priv->empty) {
+			queue_update_empty (burn);
+		}
+	} else if (event_type == GNOME_VFS_MONITOR_EVENT_DELETED) {
+		if (! burn->priv->empty) {
+			queue_update_empty (burn);
+		}
+	}
 }
 
 static gboolean
@@ -679,6 +709,10 @@ nautilus_burn_finalize (GObject *object)
 
 	g_return_if_fail (burn->priv != NULL);
 
+	if (burn->priv->empty_update_id > 0) {
+		g_source_remove (burn->priv->empty_update_id);
+	}
+
 	if (burn->priv->start_monitor_id > 0) {
 		g_source_remove (burn->priv->start_monitor_id);
 	}
