@@ -1008,9 +1008,6 @@ nautilus_burn_iso_graft_get_info (NautilusBurnIsoGraft *graft,
 	g_ptr_array_add (argv, NULL);
 
 	sub_error = NULL;
-	stdout_data = NULL;
-	stderr_data = NULL;
-	exit_status = 0;
 
 	if (! g_spawn_sync (NULL,
 			   (char **)argv->pdata,
@@ -1028,21 +1025,17 @@ nautilus_burn_iso_graft_get_info (NautilusBurnIsoGraft *graft,
 		g_error_free (sub_error);
 
 		g_ptr_array_free (argv, TRUE);
-		argv = NULL;
 
 		result = FALSE;
 		goto done;
 	}
 
 	g_ptr_array_free (argv, TRUE);
-	argv = NULL;
 
 	if (exit_status != 0 && use_joliet) {
 		if (strstr (stderr_data, "Joliet tree sort failed.") != NULL) {
 			g_free (stdout_data);
 			g_free (stderr_data);
-			stdout_data = NULL;
-			stderr_data = NULL;
 			if (ask_disable_joliet (NULL)) {
 				use_joliet = FALSE;
 				goto retry;
@@ -1241,28 +1234,31 @@ nautilus_burn_iso_make_from_graft (NautilusBurnIso             *iso,
 
 	if (res == -1) {
 		g_warning ("Cannot get free space at %s\n", dirname);
-		size = 0;
-	}
+	} else if (iso_size > size) {
+		if (flags & NAUTILUS_BURN_IMAGE_CREATE_WARN_SPACE) {
+			char *message;
 
-	g_free (dirname);
+			message = get_image_space_error_message (iso_size,
+								 size);
 
-	if (iso_size > size) {
-		char *message;
+			g_set_error (error,
+				     NAUTILUS_BURN_ISO_ERROR,
+				     NAUTILUS_BURN_ISO_ERROR_GENERAL,
+				     "%s", message);
+			g_free (message);
 
-		message = get_image_space_error_message (iso_size,
-							 size);
+			result = NAUTILUS_BURN_ISO_RESULT_ERROR;
+		} else {
+			result = NAUTILUS_BURN_ISO_RESULT_RETRY;
+		}
 
-		g_set_error (error,
-			     NAUTILUS_BURN_ISO_ERROR,
-			     NAUTILUS_BURN_ISO_ERROR_GENERAL,
-			     "%s", message);
-		g_free (message);
-
-		result = NAUTILUS_BURN_ISO_RESULT_RETRY;
+		g_free (dirname);
 
 		goto cleanup;
 	}
 
+	g_free (dirname);
+
 	argv = g_ptr_array_new ();
 	g_ptr_array_add (argv, "mkisofs");
 	g_ptr_array_add (argv, "-r");
@@ -1518,26 +1514,26 @@ nautilus_burn_iso_make_from_drive (NautilusBurnIso             *iso,
 
 	if (res == -1) {
 		g_warning ("Cannot get free space at %s\n", dirname);
+		g_free (dirname);
+	} else if (iso_size > size) {
+		g_free (dirname);
+		if (flags & NAUTILUS_BURN_IMAGE_CREATE_WARN_SPACE) {
+			char *message;
 
-		size = 0;
-	}
+			message = get_image_space_error_message (iso_size,
+								 size);
 
-	g_free (dirname);
+			g_set_error (error, NAUTILUS_BURN_ISO_ERROR,
+				     NAUTILUS_BURN_ISO_ERROR_GENERAL,
+				     "%s", message);
+			g_free (message);
 
-	if (iso_size > size) {
-		char *message;
+			result = NAUTILUS_BURN_ISO_RESULT_ERROR;
+		} else {
+			result = NAUTILUS_BURN_ISO_RESULT_RETRY;
+		}
 
-		message = get_image_space_error_message (iso_size,
-							 size);
-
-		g_set_error (error, NAUTILUS_BURN_ISO_ERROR,
-			     NAUTILUS_BURN_ISO_ERROR_GENERAL,
-			     "%s", message);
-		g_free (message);
-
-		result = NAUTILUS_BURN_ISO_RESULT_RETRY;
-
-		goto cleanup;
+		return result;
 	}
 
 	filename_arg = NULL;
@@ -1588,8 +1584,6 @@ nautilus_burn_iso_make_from_drive (NautilusBurnIso             *iso,
 	g_free (filename_arg);
 	g_free (toc_filename_arg);
 
- cleanup:
-
 	return result;
 }
 
