@@ -36,9 +36,6 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/ioctl.h>
-#ifdef __FreeBSD__
-#include <sys/uio.h>
-#endif /* __FreeBSD__ */
 #include <signal.h>
 #include <time.h>
 
@@ -712,7 +709,8 @@ cdrecord_stderr_line (NautilusBurnProcess   *process,
 		process->expect_process_to_die = TRUE;
 
 		insert_cd_retry (process, !res, FALSE, FALSE);
-	} else if (strstr (line, "Data may not fit on current disk") != NULL) {
+	} else if ((strstr (line, "Data may not fit on current disk") != NULL)
+		   || (strstr (line, "Data may not fit on standard") != NULL)) {
 		nautilus_burn_process_set_error (process,
 						 _("The files selected did not fit on the CD."),
 						 NAUTILUS_BURN_RECORDER_RESULT_ERROR);
