@@ -654,7 +654,7 @@ create_default_label (void)
 
         now = g_date_new ();
 
-        g_date_set_time (now, time (NULL));
+        g_date_set_time_t (now, time (NULL));
 
         /*
           translators: see strftime man page for meaning of %b, %d and %Y
